==> thonny-pi-1.0b1.tar.gz: thonny-pi-1.0b1/setup.py <==
from setuptools import setup

setup (
        name="thonny-pi",
        version="1.0b1",
        description="Raspberry Pi customizations for Thonny IDE",
        long_description="""Thonny plug-in which adds Raspberry Pi theme and sets Rasberry specific defaults. More info about Thonny: https://thonny.org.""",
        url="https://bitbucket.org/plas/thonny-pi/",
        author="Aivar Annamaa",
        author_email="aivar.annamaa@gmail.com",
        license="MIT",
        classifiers=[
          "Environment :: MacOS X",
          "Environment :: Win32 (MS Windows)",
          "Environment :: X11 Applications",
          "Intended Audience :: Developers",
          "Intended Audience :: Education",
          "Intended Audience :: End Users/Desktop",
          "License :: Freeware",
          "License :: OSI Approved :: MIT License",
          "Natural Language :: English",
          "Operating System :: MacOS",
          "Operating System :: Microsoft :: Windows",
          "Operating System :: POSIX",
          "Operating System :: POSIX :: Linux",
          "Programming Language :: Python",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3 :: Only",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
          "Topic :: Education",
          "Topic :: Software Development",
          "Topic :: Software Development :: Embedded Systems",
        ],
        keywords="IDE education programming  Thonny Raspberry Pi",
        platforms=["Windows", "macOS", "Linux"],
        python_requires=">=3.5",
        package_data={'thonnycontrib.pi_theme': ['res/*']},
        install_requires=["thonny>=3.0.0b1"],
        packages=["thonnycontrib.pi"],
)

==> thonny-pi-1.1.tar.gz: thonny-pi-1.1/setup.py <==
from setuptools import setup

setup (
        name="thonny-pi",
        version="1.1",
        description="Raspberry Pi customizations for Thonny IDE",
        long_description="""Thonny plug-in which adds Raspberry Pi theme and sets Rasberry specific defaults. More info about Thonny: https://thonny.org.""",
        url="https://bitbucket.org/plas/thonny-pi/",
        author="Aivar Annamaa",
        author_email="aivar.annamaa@gmail.com",
        license="MIT",
        classifiers=[
          "Environment :: MacOS X",
          "Environment :: Win32 (MS Windows)",
          "Environment :: X11 Applications",
          "Intended Audience :: Developers",
          "Intended Audience :: Education",
          "Intended Audience :: End Users/Desktop",
          "License :: Freeware",
          "License :: OSI Approved :: MIT License",
          "Natural Language :: English",
          "Operating System :: MacOS",
          "Operating System :: Microsoft :: Windows",
          "Operating System :: POSIX",
          "Operating System :: POSIX :: Linux",
          "Programming Language :: Python",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3 :: Only",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
          "Topic :: Education",
          "Topic :: Software Development",
          "Topic :: Software Development :: Embedded Systems",
        ],
        keywords="IDE education programming  Thonny Raspberry Pi",
        platforms=["Windows", "macOS", "Linux"],
        python_requires=">=3.5",
        package_data={'thonnycontrib.pi': ['res/*']},
        install_requires=["thonny>=3.0.0"],
        packages=["thonnycontrib.pi"],
)
